@@ -3,7 +3,7 @@
 	/**
 	 * Manage views in a database
 	 *
-	 * $Id: views.php,v 1.51 2004/09/07 13:58:21 jollytoad Exp $
+	 * $Id: views.php,v 1.75 2007/12/15 22:57:43 ioguix Exp $
 	 */
 
 	// Include application functions
@@ -12,38 +12,36 @@
 	
 	$action = (isset($_REQUEST['action'])) ? $_REQUEST['action'] : '';
 	if (!isset($msg)) $msg = '';
-	$PHP_SELF = $_SERVER['PHP_SELF'];
 
 	/**
 	 * Ask for select parameters and perform select
 	 */
 	function doSelectRows($confirm, $msg = '') {
-		global $data, $misc;
+		global $data, $misc, $_no_output;  
 		global $lang;
-		global $PHP_SELF;
 
 		if ($confirm) {
 			$misc->printTrail('view');
 			$misc->printTitle($lang['strselect'], 'pg.sql.select');
 			$misc->printMsg($msg);
 
-			$attrs = &$data->getTableAttributes($_REQUEST['view']);
+			$attrs = $data->getTableAttributes($_REQUEST['view']);
 
-			echo "<form action=\"$PHP_SELF\" method=\"get\" name=\"selectform\">\n";
+			echo "<form action=\"views.php\" method=\"post\" id=\"selectform\">\n";
 			if ($attrs->recordCount() > 0) {
 				// JavaScript for select all feature
-				echo "<script language=\"JavaScript\">\n";
-				echo "<!--\n";
+				echo "<script type=\"text/javascript\">\n";
+				echo "//<![CDATA[\n";
 				echo "	function selectAll() {\n";
-				echo "		for (var i=0; i<document.selectform.elements.length; i++) {\n";
-				echo "			var e = document.selectform.elements[i];\n";
-				echo "			if (e.name.indexOf('show') == 0) e.checked = document.selectform.selectall.checked;\n";
+				echo "		for (var i=0; i<document.getElementById('selectform').elements.length; i++) {\n";
+				echo "			var e = document.getElementById('selectform').elements[i];\n";
+				echo "			if (e.name.indexOf('show') == 0) e.checked = document.getElementById('selectform').selectall.checked;\n";
 				echo "		}\n";
 				echo "	}\n";
-				echo "//-->\n";
+				echo "//]]>\n";
 				echo "</script>\n";
 	
-				echo "<table>\n<tr>";
+				echo "<table>\n";
 
 				// Output table header
 				echo "<tr><th class=\"data\">{$lang['strshow']}</th><th class=\"data\">{$lang['strcolumn']}</th>";
@@ -52,36 +50,36 @@
 
 				$i = 0;
 				while (!$attrs->EOF) {
-					$attrs->f['attnotnull'] = $data->phpBool($attrs->f['attnotnull']);
+					$attrs->fields['attnotnull'] = $data->phpBool($attrs->fields['attnotnull']);
 					// Set up default value if there isn't one already
-					if (!isset($_REQUEST['values'][$attrs->f['attname']]))
-						$_REQUEST['values'][$attrs->f['attname']] = null;
-					if (!isset($_REQUEST['ops'][$attrs->f['attname']]))
-						$_REQUEST['ops'][$attrs->f['attname']] = null;
+					if (!isset($_REQUEST['values'][$attrs->fields['attname']]))
+						$_REQUEST['values'][$attrs->fields['attname']] = null;
+					if (!isset($_REQUEST['ops'][$attrs->fields['attname']]))
+						$_REQUEST['ops'][$attrs->fields['attname']] = null;
 					// Continue drawing row
 					$id = (($i % 2) == 0 ? '1' : '2');
-					echo "<tr>\n";
-					echo "<td class=\"data{$id}\" nowrap=\"nowrap\">";
-					echo "<input type=\"checkbox\" name=\"show[", htmlspecialchars($attrs->f['attname']), "]\"",
-						isset($_REQUEST['show'][$attrs->f['attname']]) ? ' checked="checked"' : '', " /></td>";
-					echo "<td class=\"data{$id}\" nowrap=\"nowrap\">", $misc->printVal($attrs->f['attname']), "</td>";
-					echo "<td class=\"data{$id}\" nowrap=\"nowrap\">", $misc->printVal($data->formatType($attrs->f['type'], $attrs->f['atttypmod'])), "</td>";
-					echo "<td class=\"data{$id}\" nowrap=\"nowrap\">";
-					echo "<select name=\"ops[{$attrs->f['attname']}]\">\n";
+					echo "<tr class=\"data{$id}\">\n";
+					echo "<td style=\"white-space:nowrap;\">";
+					echo "<input type=\"checkbox\" name=\"show[", htmlspecialchars($attrs->fields['attname']), "]\"",
+						isset($_REQUEST['show'][$attrs->fields['attname']]) ? ' checked="checked"' : '', " /></td>";
+					echo "<td style=\"white-space:nowrap;\">", $misc->printVal($attrs->fields['attname']), "</td>";
+					echo "<td style=\"white-space:nowrap;\">", $misc->printVal($data->formatType($attrs->fields['type'], $attrs->fields['atttypmod'])), "</td>";
+					echo "<td style=\"white-space:nowrap;\">";
+					echo "<select name=\"ops[{$attrs->fields['attname']}]\">\n";
 					foreach (array_keys($data->selectOps) as $v) {
-						echo "<option value=\"", htmlspecialchars($v), "\"", ($v == $_REQUEST['ops'][$attrs->f['attname']]) ? ' selected="selected"' : '', 
+						echo "<option value=\"", htmlspecialchars($v), "\"", ($v == $_REQUEST['ops'][$attrs->fields['attname']]) ? ' selected="selected"' : '', 
 						">", htmlspecialchars($v), "</option>\n";
 					}
-					echo "</select>\n";
-					echo "<td class=\"data{$id}\" nowrap=\"nowrap\">", $data->printField("values[{$attrs->f['attname']}]",
-						$_REQUEST['values'][$attrs->f['attname']], $attrs->f['type']), "</td>";
+					echo "</select></td>\n";
+					echo "<td style=\"white-space:nowrap;\">", $data->printField("values[{$attrs->fields['attname']}]",
+						$_REQUEST['values'][$attrs->fields['attname']], $attrs->fields['type']), "</td>";
 					echo "</tr>\n";
 					$i++;
 					$attrs->moveNext();
 				}
 				// Select all checkbox
-				echo "<tr><td colspan=\"5\"><input type=\"checkbox\" name=\"selectall\" onClick=\"javascript:selectAll()\" />{$lang['strselectallfields']}</td>";
-				echo "</table></p>\n";
+				echo "<tr><td colspan=\"5\"><input type=\"checkbox\" id=\"selectall\" name=\"selectall\" onclick=\"javascript:selectAll()\" /><label for=\"selectall\">{$lang['strselectallfields']}</label></td></tr>";
+				echo "</table>\n";
 			}
 			else echo "<p>{$lang['strinvalidparam']}</p>\n";
 
@@ -94,28 +92,29 @@
 			echo "</form>\n";
 		}
 		else {
-			if (!isset($_GET['show'])) $_GET['show'] = array();
-			if (!isset($_GET['values'])) $_GET['values'] = array();
-			if (!isset($_GET['nulls'])) $_GET['nulls'] = array();
+			if (!isset($_POST['show'])) $_POST['show'] = array();
+			if (!isset($_POST['values'])) $_POST['values'] = array();
+			if (!isset($_POST['nulls'])) $_POST['nulls'] = array();
 			
 			// Verify that they haven't supplied a value for unary operators
-			foreach ($_GET['ops'] as $k => $v) {
-				if ($data->selectOps[$v] == 'p' && $_GET['values'][$k] != '') {
+			foreach ($_POST['ops'] as $k => $v) {
+				if ($data->selectOps[$v] == 'p' && $_POST['values'][$k] != '') {
 					doSelectRows(true, $lang['strselectunary']);
 					return;
 				}
 			}
-						
-			if (sizeof($_GET['show']) == 0)
-				doSelectRows(true, $lang['strselectneedscol']);			
+	
+			if (sizeof($_POST['show']) == 0)
+				doSelectRows(true, $lang['strselectneedscol']);
 			else {
 				// Generate query SQL
-				$query = $data->getSelectSQL($_REQUEST['view'], array_keys($_GET['show']),
-					$_GET['values'], $_GET['ops']);
+				$query = $data->getSelectSQL($_REQUEST['view'], array_keys($_POST['show']),
+					$_POST['values'], $_POST['ops']);
 				$_REQUEST['query'] = $query;
-				$_REQUEST['return_url'] = "views.php?action=confselectrows&{$misc->href}&view={$_REQUEST['view']}";
+				$_REQUEST['return_url'] = "views.php?action=confselectrows&amp;{$misc->href}&amp;view=". urlencode($_REQUEST['view']);
 				$_REQUEST['return_desc'] = $lang['strback'];
-
+			
+                                $_no_output = true;	
 				include('./display.php');
 				exit;
 			}
@@ -128,34 +127,72 @@
 	 */
 	function doDrop($confirm) {
 		global $data, $misc;
-		global $PHP_SELF, $lang, $_reload_browser;
+		global $lang, $_reload_browser;
+
+		if (empty($_REQUEST['view']) && empty($_REQUEST['ma'])) {
+			doDefault($lang['strspecifyviewtodrop']);
+			exit();
+		}
 
 		if ($confirm) { 
 			$misc->printTrail('view');
 			$misc->printTitle($lang['strdrop'],'pg.view.drop');
 			
-			echo "<p>", sprintf($lang['strconfdropview'], $misc->printVal($_REQUEST['view'])), "</p>\n";
+			echo "<form action=\"views.php\" method=\"post\">\n";
 			
-			echo "<form action=\"$PHP_SELF\" method=\"post\">\n";
-			echo "<input type=\"hidden\" name=\"action\" value=\"drop\" />\n";
-			echo "<input type=\"hidden\" name=\"view\" value=\"", htmlspecialchars($_REQUEST['view']), "\" />\n";
-			echo $misc->form;
-			// Show cascade drop option if supportd
-			if ($data->hasDropBehavior()) {
-				echo "<p><input type=\"checkbox\" name=\"cascade\" /> {$lang['strcascade']}</p>\n";
+			//If multi drop
+			if (isset($_REQUEST['ma'])) {
+				foreach($_REQUEST['ma'] as $v) {
+					$a = unserialize(htmlspecialchars_decode($v, ENT_QUOTES));
+					echo "<p>", sprintf($lang['strconfdropview'], $misc->printVal($a['view'])), "</p>\n";
+					echo '<input type="hidden" name="view[]" value="', htmlspecialchars($a['view']), "\" />\n";
+				}
 			}
+			else {
+				echo "<p>", sprintf($lang['strconfdropview'], $misc->printVal($_REQUEST['view'])), "</p>\n";
+				echo "<input type=\"hidden\" name=\"view\" value=\"", htmlspecialchars($_REQUEST['view']), "\" />\n";
+			}
+			
+			echo "<input type=\"hidden\" name=\"action\" value=\"drop\" />\n";
+			
+			echo $misc->form;
+			echo "<p><input type=\"checkbox\" id=\"cascade\" name=\"cascade\" /> <label for=\"cascade\">{$lang['strcascade']}</label></p>\n";
 			echo "<input type=\"submit\" name=\"drop\" value=\"{$lang['strdrop']}\" />\n";
 			echo "<input type=\"submit\" name=\"cancel\" value=\"{$lang['strcancel']}\" />\n";
 			echo "</form>\n";
 		}
 		else {
-			$status = $data->dropView($_POST['view'], isset($_POST['cascade']));
-			if ($status == 0) {
-				$_reload_browser = true;
-				doDefault($lang['strviewdropped']);
+			if (is_array($_POST['view'])) {
+				$msg='';
+				$status = $data->beginTransaction();
+				if ($status == 0) {
+					foreach($_POST['view'] as $s) {
+						$status = $data->dropView($s, isset($_POST['cascade']));
+						if ($status == 0)
+							$msg.= sprintf('%s: %s<br />', htmlentities($s), $lang['strviewdropped']);
+						else {
+							$data->endTransaction();
+							doDefault(sprintf('%s%s: %s<br />', $msg, htmlentities($s), $lang['strviewdroppedbad']));
+							return;
+						}
+					}
+				}
+				if($data->endTransaction() == 0) {
+					// Everything went fine, back to the Default page....
+					$_reload_browser = true;
+					doDefault($msg);
+				}
+				else doDefault($lang['strviewdroppedbad']);
+			}
+			else{
+				$status = $data->dropView($_POST['view'], isset($_POST['cascade']));
+				if ($status == 0) {
+					$_reload_browser = true;
+					doDefault($lang['strviewdropped']);
+				}
+				else
+					doDefault($lang['strviewdroppedbad']);
 			}
-			else
-				doDefault($lang['strviewdroppedbad']);
 		}
 		
 	}
@@ -165,7 +202,7 @@
 	 */
 	function doSetParamsCreate($msg = '') {
 		global $data, $misc;
-		global $PHP_SELF, $lang;
+		global $lang;
 		
 		// Check that they've chosen tables for the view definition
 		if (!isset($_POST['formTables']) ) doWizardCreate($lang['strviewneedsdef']);
@@ -185,51 +222,46 @@
 			}
 			
 			$linkCount = $tblCount;
-			// If we can get foreign key info then get our linking keys
-			if ($data->hasForeignKeysInfo()) {
-				$rsLinkKeys = $data->getLinkingKeys($arrSelTables);
-				$linkCount = $rsLinkKeys->recordCount() > $tblCount ? $rsLinkKeys->recordCount() : $tblCount;
-			}
+			
+			//get linking keys
+			$rsLinkKeys = $data->getLinkingKeys($arrSelTables);
+			$linkCount = $rsLinkKeys->recordCount() > $tblCount ? $rsLinkKeys->recordCount() : $tblCount;
 			
 			$arrFields = array(); //array that will hold all our table/field names
 			
 			//if we have schemas we need to specify the correct schema for each table we're retrieiving
 			//with getTableAttributes
-			$curSchema = $data->hasSchemas() ? $data->_schema : NULL;
+			$curSchema = $data->_schema;
 			for ($i = 0; $i < $tblCount; $i++) {
-				if ($data->hasSchemas() && $data->_schema != $arrSelTables[$i]['schemaname']) {
+				if ($data->_schema != $arrSelTables[$i]['schemaname']) {
 					$data->setSchema($arrSelTables[$i]['schemaname']);
 				}
 				
-				$attrs = &$data->getTableAttributes($arrSelTables[$i]['tablename']);
+				$attrs = $data->getTableAttributes($arrSelTables[$i]['tablename']);
 				while (!$attrs->EOF) {
-					if ($data->hasSchemas() ) {
-						$arrFields["{$arrSelTables[$i]['schemaname']}.{$arrSelTables[$i]['tablename']}.{$attrs->f['attname']}"] = serialize(array('schemaname' => $arrSelTables[$i]['schemaname'], 'tablename' => $arrSelTables[$i]['tablename'], 'fieldname' => $attrs->f['attname']) );
-					}
-					else {
-						$arrFields["{$arrSelTables[$i]['tablename']}.{$attrs->f['attname']}"] = serialize(array('schemaname' => NULL, 'tablename' => $arrSelTables[$i]['tablename'], 'fieldname' => $attrs->f['attname']) );
-					}
+					$arrFields["{$arrSelTables[$i]['schemaname']}.{$arrSelTables[$i]['tablename']}.{$attrs->fields['attname']}"] = serialize(array(
+						'schemaname' => $arrSelTables[$i]['schemaname'], 
+						'tablename' => $arrSelTables[$i]['tablename'], 
+						'fieldname' => $attrs->fields['attname']) 
+					);
 					$attrs->moveNext();
 				}
 				
-				//reset back to our original schema in case we switched from it
-				if ($data->hasSchemas() ) {
-					$data->setSchema($curSchema);
-				}
+				$data->setSchema($curSchema);
 			}
 			asort($arrFields);
 			
-			echo "<form action=\"$PHP_SELF\" method=\"post\">\n";
+			echo "<form action=\"views.php\" method=\"post\">\n";
 			echo "<table>\n";
 			echo "<tr><th class=\"data\">{$lang['strviewname']}</th></tr>";
 			echo "<tr>\n<td class=\"data1\">\n";
 			// View name
-			echo "<input name=\"formView\" id=\"formView\" value=\"", htmlspecialchars($_REQUEST['formView']), "\" size=\"32\" maxlength=\"{$data->_maxNameLen}\" />\n";
+			echo "<input name=\"formView\" value=\"", htmlspecialchars($_REQUEST['formView']), "\" size=\"32\" maxlength=\"{$data->_maxNameLen}\" />\n";
 			echo "</td>\n</tr>\n";
 			echo "<tr><th class=\"data\">{$lang['strcomment']}</th></tr>";
 			echo "<tr>\n<td class=\"data1\">\n";
 			// View comments
-			echo "<textarea name=\"formComment\" rows=\"3\" cols=\"32\" wrap=\"virtual\">", 
+			echo "<textarea name=\"formComment\" rows=\"3\" cols=\"32\">", 
 				htmlspecialchars($_REQUEST['formComment']), "</textarea>\n";
 			echo "</td>\n</tr>\n";
 			echo "</table>\n";
@@ -239,7 +271,10 @@
 			echo "<tr><th class=\"data\">{$lang['strcolumns']}</th></tr>";
 			echo "<tr>\n<td class=\"data1\">\n";
 			echo GUI::printCombo($arrFields, 'formFields[]', false, '', true);
-			echo "</td>\n</tr>\n</table>\n<br />\n";
+			echo "</td>\n</tr>";
+			echo "<tr><td><input type=\"radio\" name=\"dblFldMeth\" id=\"dblFldMeth1\" value=\"rename\" /><label for=\"dblFldMeth1\">{$lang['strrenamedupfields']}</label>";
+			echo "<br /><input type=\"radio\" name=\"dblFldMeth\" id=\"dblFldMeth2\" value=\"drop\" /><label for=\"dblFldMeth2\">{$lang['strdropdupfields']}</label>";
+			echo "<br /><input type=\"radio\" name=\"dblFldMeth\" id=\"dblFldMeth3\" value=\"\" checked=\"checked\" /><label for=\"dblFldMeth3\">{$lang['strerrordupfields']}</label></td></tr></table><br />";
 			
 			// Output the Linking keys combo boxes
 			echo "<table>\n";
@@ -250,9 +285,9 @@
 				if (!isset($formLink[$i]['operator'])) $formLink[$i]['operator'] = 'INNER JOIN';
 				echo "<tr>\n<td class=\"$rowClass\">\n";
 				
-				if ($data->hasForeignKeysInfo() && !$rsLinkKeys->EOF) {
-					$curLeftLink = htmlspecialchars(serialize(array('schemaname' => $rsLinkKeys->f['p_schema'], 'tablename' => $rsLinkKeys->f['p_table'], 'fieldname' => $rsLinkKeys->f['p_field']) ) );
-					$curRightLink = htmlspecialchars(serialize(array('schemaname' => $rsLinkKeys->f['f_schema'], 'tablename' => $rsLinkKeys->f['f_table'], 'fieldname' => $rsLinkKeys->f['f_field']) ) );
+				if (!$rsLinkKeys->EOF) {
+					$curLeftLink = htmlspecialchars(serialize(array('schemaname' => $rsLinkKeys->fields['p_schema'], 'tablename' => $rsLinkKeys->fields['p_table'], 'fieldname' => $rsLinkKeys->fields['p_field']) ) );
+					$curRightLink = htmlspecialchars(serialize(array('schemaname' => $rsLinkKeys->fields['f_schema'], 'tablename' => $rsLinkKeys->fields['f_table'], 'fieldname' => $rsLinkKeys->fields['f_field']) ) );
 					$rsLinkKeys->moveNext();
 				}
 				else {
@@ -288,15 +323,15 @@
 				$rowClass = $rowClass == 'data1' ? 'data2' : 'data1';
 			}
 			echo "</table>\n";
-			echo "<p><input type=\"hidden\" name=\"action\" id=\"action\" value=\"save_create_wiz\" />\n";
-			echo "<input type=\"submit\" value=\"{$lang['strcreate']}\" />\n";
-			echo "<input type=\"submit\" name=\"cancel\" value=\"{$lang['strcancel']}\" /></p>\n";
+			echo "<p><input type=\"hidden\" name=\"action\" value=\"save_create_wiz\" />\n";
 			
 			foreach ($arrSelTables AS $curTable) {
-				echo "<input type=\"hidden\" name=\"formTables[]\" id=\"formTables[]\" value=\"" . htmlspecialchars(serialize($curTable) ) . "\" />\n";
+				echo "<input type=\"hidden\" name=\"formTables[]\" value=\"" . htmlspecialchars(serialize($curTable) ) . "\" />\n";
 			}
 			
 			echo $misc->form;
+			echo "<input type=\"submit\" value=\"{$lang['strcreate']}\" />\n";
+			echo "<input type=\"submit\" name=\"cancel\" value=\"{$lang['strcancel']}\" /></p>\n";
 			echo "</form>\n";
 		}
 	}
@@ -306,40 +341,35 @@
 	 */
 	function doWizardCreate($msg = '') {
 		global $data, $misc;
-		global $PHP_SELF, $lang;
+		global $lang;
 		
-		$tables = &$data->getTables(true);
+		$tables = $data->getTables(true);
 		
 		$misc->printTrail('schema');
 		$misc->printTitle($lang['strcreateviewwiz'], 'pg.view.create');
 		$misc->printMsg($msg);
 		
-		echo "<form action=\"$PHP_SELF\" method=\"post\">\n";
+		echo "<form action=\"views.php\" method=\"post\">\n";
 		echo "<table>\n";
 		echo "<tr><th class=\"data\">{$lang['strtables']}</th></tr>";		
 		echo "<tr>\n<td class=\"data1\">\n";		
 		
 		$arrTables = array();
-		while (!$tables->EOF) {						
+		while (!$tables->EOF) {
 			$arrTmp = array();
-			$arrTmp['schemaname'] = $tables->f['nspname'];
-			$arrTmp['tablename'] = $tables->f['relname'];
-			if ($data->hasSchemas() ) { //if schemas aren't available don't show them in the interface
-				$arrTables[$tables->f['nspname'] . '.' . $tables->f['relname']] = serialize($arrTmp);
-			}
-			else {
-				$arrTables[$tables->f['relname']] = serialize($arrTmp);
-			}
+			$arrTmp['schemaname'] = $tables->fields['nspname'];
+			$arrTmp['tablename'] = $tables->fields['relname'];
+			$arrTables[$tables->fields['nspname'] . '.' . $tables->fields['relname']] = serialize($arrTmp);
 			$tables->moveNext();
 		}		
 		echo GUI::printCombo($arrTables, 'formTables[]', false, '', true);			
 		
 		echo "</td>\n</tr>\n";		
 		echo "</table>\n";		
-		echo "<p><input type=\"submit\" value=\"{$lang['strnext']}\" />\n";
-		echo "<input type=\"submit\" name=\"cancel\" value=\"{$lang['strcancel']}\" /></p>\n";
-		echo "<input type=\"hidden\" name=\"action\" id=\"action\" value=\"set_params_create\" />\n";
+		echo "<p><input type=\"hidden\" name=\"action\" value=\"set_params_create\" />\n";
 		echo $misc->form;
+		echo "<input type=\"submit\" value=\"{$lang['strnext']}\" />\n";
+		echo "<input type=\"submit\" name=\"cancel\" value=\"{$lang['strcancel']}\" /></p>\n";
 		echo "</form>\n";
 	}
 	
@@ -348,7 +378,7 @@
 	 */
 	function doCreate($msg = '') {
 		global $data, $misc, $conf;
-		global $PHP_SELF, $lang;
+		global $lang;
 		
 		if (!isset($_REQUEST['formView'])) $_REQUEST['formView'] = '';
 		if (!isset($_REQUEST['formDefinition'])) $_REQUEST['formDefinition'] = 'SELECT ';
@@ -358,16 +388,16 @@
 		$misc->printTitle($lang['strcreateview'], 'pg.view.create');
 		$misc->printMsg($msg);
 		
-		echo "<form action=\"$PHP_SELF\" method=\"post\">\n";
-		echo "<table width=\"100%\">\n";
+		echo "<form action=\"views.php\" method=\"post\">\n";
+		echo "<table style=\"width: 100%\">\n";
 		echo "\t<tr>\n\t\t<th class=\"data left required\">{$lang['strname']}</th>\n";
 		echo "\t<td class=\"data1\"><input name=\"formView\" size=\"32\" maxlength=\"{$data->_maxNameLen}\" value=\"", 
 			htmlspecialchars($_REQUEST['formView']), "\" /></td>\n\t</tr>\n";
 		echo "\t<tr>\n\t\t<th class=\"data left required\">{$lang['strdefinition']}</th>\n";
-		echo "\t<td class=\"data1\"><textarea style=\"width:100%;\" rows=\"10\" cols=\"50\" name=\"formDefinition\" wrap=\"virtual\">", 
+		echo "\t<td class=\"data1\"><textarea style=\"width:100%;\" rows=\"10\" cols=\"50\" name=\"formDefinition\">", 
 			htmlspecialchars($_REQUEST['formDefinition']), "</textarea></td>\n\t</tr>\n";
 		echo "\t<tr>\n\t\t<th class=\"data left\">{$lang['strcomment']}</th>\n";
-		echo "\t\t<td class=\"data1\"><textarea name=\"formComment\" rows=\"3\" cols=\"32\" wrap=\"virtual\">", 
+		echo "\t\t<td class=\"data1\"><textarea name=\"formComment\" rows=\"3\" cols=\"32\">", 
 			htmlspecialchars($_REQUEST['formComment']), "</textarea></td>\n\t</tr>\n";
 		echo "</table>\n";
 		echo "<p><input type=\"hidden\" name=\"action\" value=\"save_create\" />\n";
@@ -408,17 +438,30 @@
 		if (!strlen($_POST['formView']) ) doSetParamsCreate($lang['strviewneedsname']);
 		else if (!isset($_POST['formFields']) || !count($_POST['formFields']) ) doSetParamsCreate($lang['strviewneedsfields']);
 		else {						
-			$selFields = '';						
+			$selFields = '';
+
+			if (! empty($_POST['dblFldMeth']) )
+				$tmpHsh = array();
+
 			foreach ($_POST['formFields'] AS $curField) {
 				$arrTmp = unserialize($curField);
-				if ($data->hasSchemas() ) {					
-					$selFields .= strlen($selFields) ? ", \"{$arrTmp['schemaname']}\".\"{$arrTmp['tablename']}\".\"{$arrTmp['fieldname']}\"" : "\"{$arrTmp['schemaname']}\".\"{$arrTmp['tablename']}\".\"{$arrTmp['fieldname']}\"";
+				$data->fieldArrayClean($arrTmp);
+				if (! empty($_POST['dblFldMeth']) ) { // doublon control
+					if (empty($tmpHsh[$arrTmp['fieldname']])) { // field does not exist
+						$selFields .= "\"{$arrTmp['schemaname']}\".\"{$arrTmp['tablename']}\".\"{$arrTmp['fieldname']}\", ";
+						$tmpHsh[$arrTmp['fieldname']] = 1;
+					} else if ($_POST['dblFldMeth'] == 'rename') { // field exist and must be renamed
+						$tmpHsh[$arrTmp['fieldname']]++;
+						$selFields .= "\"{$arrTmp['schemaname']}\".\"{$arrTmp['tablename']}\".\"{$arrTmp['fieldname']}\" AS \"{$arrTmp['schemaname']}_{$arrTmp['tablename']}_{$arrTmp['fieldname']}{$tmpHsh[$arrTmp['fieldname']]}\", ";
+					}
+					/* field already exist, just ignore this one */
+				} else { // no doublon control
+					$selFields .= "\"{$arrTmp['schemaname']}\".\"{$arrTmp['tablename']}\".\"{$arrTmp['fieldname']}\", ";
 				}
-				else {
-					$selFields .= strlen($selFields) ? ", \"{$arrTmp['tablename']}\".\"{$arrTmp['fieldname']}\"" : "\"{$arrTmp['tablename']}\".\"{$arrTmp['fieldname']}\"";
-				}				
-			}			
-			
+			}
+
+			$selFields = substr($selFields, 0, -2);
+			unset($arrTmp, $tmpHsh);
 			$linkFields = '';
 
 			// If we have links, out put the JOIN ... ON statements
@@ -443,9 +486,11 @@
 							
 							$arrLeftLink = unserialize($curLink['leftlink']);
 							$arrRightLink = unserialize($curLink['rightlink']);
+							$data->fieldArrayClean($arrLeftLink);
+							$data->fieldArrayClean($arrRightLink);
 							
-							$tbl1 = $data->hasSchemas() ? "\"{$arrLeftLink['schemaname']}\".\"{$arrLeftLink['tablename']}\"" : $arrLeftLink['tablename'];
-							$tbl2 = $data->hasSchemas() ? "\"{$arrRightLink['schemaname']}\".\"{$arrRightLink['tablename']}\"" : $arrRightLink['tablename'];
+							$tbl1 = "\"{$arrLeftLink['schemaname']}\".\"{$arrLeftLink['tablename']}\"";
+							$tbl2 = "\"{$arrRightLink['schemaname']}\".\"{$arrRightLink['tablename']}\"";
 							
 							if ( (!in_array($curLink, $arrJoined) && in_array($tbl1, $arrUsedTbls)) || !count($arrJoined) ) {
 								
@@ -453,12 +498,8 @@
 								// This can (and should be) more optimized for multi-column foreign keys
 								$adj_tbl2 = in_array($tbl2, $arrUsedTbls) ? "$tbl2 AS alias_ppa_" . mktime() : $tbl2;
 								
-								if ($data->hasSchemas() ) {
-									$linkFields .= strlen($linkFields) ? "{$curLink['operator']} $adj_tbl2 ON (\"{$arrLeftLink['schemaname']}\".\"{$arrLeftLink['tablename']}\".\"{$arrLeftLink['fieldname']}\" = \"{$arrRightLink['schemaname']}\".\"{$arrRightLink['tablename']}\".\"{$arrRightLink['fieldname']}\") " : "$tbl1 {$curLink['operator']} $adj_tbl2 ON (\"{$arrLeftLink['schemaname']}\".\"{$arrLeftLink['tablename']}\".\"{$arrLeftLink['fieldname']}\" = \"{$arrRightLink['schemaname']}\".\"{$arrRightLink['tablename']}\".\"{$arrRightLink['fieldname']}\") ";
-								}
-								else {
-									$linkFields .= strlen($linkFields) ? "{$curLink['operator']} $adj_tbl2 ON (\"{$arrLeftLink['tablename']}\".\"{$arrLeftLink['fieldname']}\" = \"{$arrRightLink['tablename']}\".\"{$arrRightLink['fieldname']}\") " : "$tbl1 {$curLink['operator']} $adj_tbl2 ON (\"{$arrLeftLink['tablename']}\".\"{$arrLeftLink['fieldname']}\" = \"{$arrRightLink['tablename']}\".\"{$arrRightLink['fieldname']}\") ";
-								}
+								$linkFields .= strlen($linkFields) ? "{$curLink['operator']} $adj_tbl2 ON (\"{$arrLeftLink['schemaname']}\".\"{$arrLeftLink['tablename']}\".\"{$arrLeftLink['fieldname']}\" = \"{$arrRightLink['schemaname']}\".\"{$arrRightLink['tablename']}\".\"{$arrRightLink['fieldname']}\") " 
+									: "$tbl1 {$curLink['operator']} $adj_tbl2 ON (\"{$arrLeftLink['schemaname']}\".\"{$arrLeftLink['tablename']}\".\"{$arrLeftLink['fieldname']}\" = \"{$arrRightLink['schemaname']}\".\"{$arrRightLink['tablename']}\".\"{$arrRightLink['fieldname']}\") ";
 								
 								$arrJoined[] = $curLink;
 								if (!in_array($tbl1, $arrUsedTbls) )  $arrUsedTbls[] = $tbl1;
@@ -475,12 +516,8 @@
 			if (!strlen($linkFields) ) {
 				foreach ($_POST['formTables'] AS $curTable) {
 					$arrTmp = unserialize($curTable);
-					if ($data->hasSchemas() ) {
-						$linkFields .= strlen($linkFields) ? ", \"{$arrTmp['schemaname']}\".\"{$arrTmp['tablename']}\"" : "\"{$arrTmp['schemaname']}\".\"{$arrTmp['tablename']}\"";
-					}
-					else {
-						$linkFields .= strlen($linkFields) ? ", \"{$arrTmp['tablename']}\"" : "\"{$arrTmp['tablename']}\"";
-					}
+					$data->fieldArrayClean($arrTmp);
+					$linkFields .= strlen($linkFields) ? ", \"{$arrTmp['schemaname']}\".\"{$arrTmp['tablename']}\"" : "\"{$arrTmp['schemaname']}\".\"{$arrTmp['tablename']}\"";
 				}
 			}
 			
@@ -489,12 +526,9 @@
 				foreach ($_POST['formCondition'] AS $curCondition) {
 					if (strlen($curCondition['field']) && strlen($curCondition['txt']) ) {
 						$arrTmp = unserialize($curCondition['field']);
-						if ($data->hasSchemas() ) {
-							$addConditions .= strlen($addConditions) ? " AND \"{$arrTmp['schemaname']}\".\"{$arrTmp['tablename']}\".\"{$arrTmp['fieldname']}\" {$curCondition['operator']} '{$curCondition['txt']}' " : " \"{$arrTmp['schemaname']}\".\"{$arrTmp['tablename']}\".\"{$arrTmp['fieldname']}\" {$curCondition['operator']} '{$curCondition['txt']}' ";
-						}
-						else {
-							$addConditions .= strlen($addConditions) ? " AND \"{$arrTmp['tablename']}\".\"{$arrTmp['fieldname']}\" {$curCondition['field']} {$curCondition['operator']} '{$curCondition['txt']}' " : " \"{$arrTmp['tablename']}\".\"{$arrTmp['fieldname']}\" {$curCondition['operator']} '{$curCondition['txt']}' ";
-						}
+						$data->fieldArrayClean($arrTmp);
+						$addConditions .= strlen($addConditions) ? " AND \"{$arrTmp['schemaname']}\".\"{$arrTmp['tablename']}\".\"{$arrTmp['fieldname']}\" {$curCondition['operator']} '{$curCondition['txt']}' " 
+							: " \"{$arrTmp['schemaname']}\".\"{$arrTmp['tablename']}\".\"{$arrTmp['fieldname']}\" {$curCondition['operator']} '{$curCondition['txt']}' ";
 					}
 				}
 			}
@@ -519,37 +553,38 @@
 	 */
 	function doDefault($msg = '') {
 		global $data, $misc, $conf;
-		global $PHP_SELF, $lang;
+		global $lang;
 		
 		$misc->printTrail('schema');
 		$misc->printTabs('schema','views');
 		$misc->printMsg($msg);
 		
-		$views = &$data->getViews();
-		
+		$views = $data->getViews();
+	
 		$columns = array(
 			'view' => array(
 				'title'	=> $lang['strview'],
-				'field'	=> 'relname',
+				'field'	=> field('relname'),
+				'url' => "redirect.php?subject=view&amp;{$misc->href}&amp;",
+				'vars'  => array('view' => 'relname'),
 			),
 			'owner' => array(
 				'title'	=> $lang['strowner'],
-				'field'	=> 'relowner',
+				'field'	=> field('relowner'),
 			),
 			'actions' => array(
 				'title'	=> $lang['stractions'],
 			),
 			'comment' => array(
 				'title'	=> $lang['strcomment'],
-				'field'	=> 'relcomment',
+				'field'	=> field('relcomment'),
 			),
 		);
 		
 		$actions = array(
-			'properties' => array(
-				'title' => $lang['strproperties'],
-				'url'	=> "redirect.php?section=view&amp;{$misc->href}&amp;",
-				'vars'	=> array('view' => 'relname'),
+			'multiactions' => array(
+				'keycols' => array('view' => 'relname'),
+				'url' => 'views.php',
 			),
 			'browse' => array(
 				'title'	=> $lang['strbrowse'],
@@ -558,31 +593,93 @@
 			),
 			'select' => array(
 				'title'	=> $lang['strselect'],
-				'url'	=> "{$PHP_SELF}?action=confselectrows&amp;{$misc->href}&amp;",
+				'url'	=> "views.php?action=confselectrows&amp;{$misc->href}&amp;",
 				'vars'	=> array('view' => 'relname'),
 			),
 			
 // Insert is possible if the relevant rule for the view has been created.
 //			'insert' => array(
 //				'title'	=> $lang['strinsert'],
-//				'url'	=> "{$PHP_SELF}?action=confinsertrow&amp;{$misc->href}&amp;",
+//				'url'	=> "views.php?action=confinsertrow&amp;{$misc->href}&amp;",
 //				'vars'	=> array('view' => 'relname'),
-//			),
+			//			),
 
+			'alter' => array(
+				'title' => $lang['stralter'],
+				'url'   => "viewproperties.php?action=confirm_alter&amp;{$misc->href}&amp;",
+				'vars'  => array('view' => 'relname'),
+			),
 			'drop' => array(
 				'title'	=> $lang['strdrop'],
-				'url'	=> "{$PHP_SELF}?action=confirm_drop&amp;{$misc->href}&amp;",
+				'url'	=> "views.php?action=confirm_drop&amp;{$misc->href}&amp;",
 				'vars'	=> array('view' => 'relname'),
+				'multiaction' => 'confirm_drop',
 			),
 		);
 		
 		$misc->printTable($views, $columns, $actions, $lang['strnoviews']);
 		
-		echo "<p><a class=\"navlink\" href=\"$PHP_SELF?action=create&{$misc->href}\">{$lang['strcreateview']}</a> |\n";
-		echo "<a class=\"navlink\" href=\"$PHP_SELF?action=wiz_create&{$misc->href}\">{$lang['strcreateviewwiz']}</a></p>\n";
+		echo "<ul class=\"navlink\">\n\t<li><a href=\"views.php?action=create&amp;{$misc->href}\">{$lang['strcreateview']}</a></li>\n";
+		echo "\t<li><a href=\"views.php?action=wiz_create&amp;{$misc->href}\">{$lang['strcreateviewwiz']}</a></li>\n</ul>\n";
 
 	}
+	
+	/**
+	 * Generate XML for the browser tree.
+	 */
+	function doTree() {
+		global $misc, $data;
+		
+		$views = $data->getViews();
+		
+		$reqvars = $misc->getRequestVars('view');
+		
+		$attrs = array(
+			'text'   => field('relname'),
+			'icon'   => 'View',
+			'iconAction' => url('display.php', $reqvars, array('view' => field('relname'))),
+			'toolTip'=> field('relcomment'),
+			'action' => url('redirect.php',	$reqvars, array('view' => field('relname'))),
+			'branch' => url('views.php', $reqvars,
+				array (
+					'action' => 'subtree',
+					'view' => field('relname')
+				)
+			)
+		);
+		
+		$misc->printTreeXML($views, $attrs);
+		exit;
+	}
+	
+	function doSubTree() {
+		global $misc, $data;
 
+		$tabs = $misc->getNavTabs('view');
+		$items = $misc->adjustTabsForTree($tabs);
+		$reqvars = $misc->getRequestVars('view');
+
+		$attrs = array(
+			'text'   => noEscape(field('title')),
+			'icon'   => field('icon'),
+			'action' => url(field('url'),	$reqvars, field('urlvars'),	array('view' => $_REQUEST['view'])),
+			'branch' => ifempty( 
+				field('branch'), '', url(field('url'), field('urlvars'), $reqvars,
+					array(
+						'action' => 'tree',
+						'view' => $_REQUEST['view']
+					)
+				)
+			),
+		);
+
+		$misc->printTreeXML($items, $attrs);
+		exit;
+	}
+	
+	if ($action == 'tree') doTree();
+	if ($action == 'subtree') dosubTree();
+	
 	$misc->printHeader($lang['strviews']);
 	$misc->printBody();
 
